class RoomList:
    descriptor_types = [
        "quality",
        "size",
        "shape",
        "color",
        "material",
        "purpose"
    ]

    descriptors = {
        "quality": [
            "musty",
            "dusty",
            "damp",
            "hot",
            "cold",
            "dark"
        ],
        "size": [
            "tiny",
            "small",
            "big",
            "huge",
            "enormous"
        ],
        "shape": [
            "round",
            "square",
            "oval",
            "pentagonal",
            "jagged"
        ],
        "color": [
            "grey",
            "black",
            "red",
            "green",
            "blue",
            "silver",
            "gold",
            "purple"
        ],
        "material": [
            "stone",
            "wood",
            "brick",
            "crystal",
            "metal"
        ],
        "purpose": [
            "torture",
            "guard",
            "dining",
            "throne",
            "trophy"
        ] 
    }